from setuptools import setup, find_packages

setup(
name='SDA-calculator',
version='0.0.1',
describtion='a short summery about my package ',
url='',
author_Email='sadra85aba@gmail.com',
authorname='sadra ',
License='MIT',
keywords='',
pakages=find_packages(),
install_requiers=['']
)
